@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -655,7 +655,7 @@ public class MailCategoriesConfigServiceImpl implements MailCategoriesConfigServ
 
         final ConfigProperty<String> hasRun = view.property(ConfigViewScope.USER.getScopeName(), MailCategoriesConfigServiceImpl.INIT_TASK_STATUS_PROPERTY, String.class);
         String currentStatus = hasRun.get();
-        if (hasRun.isDefined() && (currentStatus.equals(STATUS_RUNNING) || currentStatus.equals(STATUS_FINISHED))) {
+        if (currentStatus != null && (currentStatus.equals(STATUS_RUNNING) || currentStatus.equals(STATUS_FINISHED))) {
             return;
         }
         ThreadPoolService threadPoolService = Services.getService(ThreadPoolService.class);
