@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -90,7 +90,7 @@ public final class MailCategoriesConfigUtil implements Reloadable {
         ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -113,7 +113,7 @@ public final class MailCategoriesConfigUtil implements Reloadable {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -137,7 +137,7 @@ public final class MailCategoriesConfigUtil implements Reloadable {
         ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -164,7 +164,7 @@ public final class MailCategoriesConfigUtil implements Reloadable {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -192,7 +192,7 @@ public final class MailCategoriesConfigUtil implements Reloadable {
         ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
@@ -215,7 +215,7 @@ public final class MailCategoriesConfigUtil implements Reloadable {
         ConfigView view = viewFactory.getView(userId, contextId);
 
         ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
 
