@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -82,7 +82,8 @@ public class Activator extends HousekeepingActivator {
                     ConfigView view = service.getView(ses.getUserId(), ses.getContextId());
 
                     ComposedConfigProperty<Boolean> property = view.property(PROPERTY, Boolean.class);
-                    if (!property.isDefined() || !property.get().booleanValue()) {
+                    Boolean b = property.get();
+                    if (b == null || !b.booleanValue()) {
                         // Not enabled as per configuration
                         return FailureAwareCapabilityChecker.Result.DISABLED;
                     }
