@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,11 +27,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import javax.security.auth.Subject;
 import org.apache.jsieve.SieveException;
 import org.apache.jsieve.TagArgument;
 import org.apache.jsieve.parser.generated.Token;
-import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.jsieve.commands.ActionCommand;
@@ -54,8 +52,6 @@ import com.openexchange.mail.categories.ruleengine.MailCategoryRule;
 import com.openexchange.mail.categories.ruleengine.RuleType;
 import com.openexchange.mailfilter.Credentials;
 import com.openexchange.mailfilter.MailFilterService;
-import com.openexchange.mailfilter.properties.CredentialSource;
-import com.openexchange.mailfilter.properties.MailFilterProperty;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 import gnu.trove.list.TIntList;
@@ -156,16 +152,14 @@ public class SieveMailCategoriesRuleEngine implements MailCategoriesRuleEngine {
 
     }
 
+    /**
+     * Gets the credentials
+     *
+     * @param session The users session
+     * @return The credentials
+     */
     private Credentials getCredentials(Session session) {
-        String loginName;
-        {
-            LeanConfigurationService mailFilterConfig = services.getService(LeanConfigurationService.class);
-            String credsrc = mailFilterConfig.getProperty(session.getUserId(), session.getContextId(), MailFilterProperty.credentialSource);
-            loginName = CredentialSource.SESSION_FULL_LOGIN.name().equals(credsrc) ? session.getLogin() : session.getLoginName();
-        }
-        Subject subject = (Subject) session.getParameter("kerberosSubject");
-        String oauthToken = (String) session.getParameter(Session.PARAM_OAUTH_ACCESS_TOKEN);
-        return new Credentials(loginName, session.getPassword(), session.getUserId(), session.getContextId(), null, subject, oauthToken);
+        return new Credentials(session);
     }
 
     private Rule mailCategoryRule2SieveRule(MailCategoryRule rule, RuleType type) throws SieveException {
@@ -194,7 +188,7 @@ public class SieveMailCategoriesRuleEngine implements MailCategoriesRuleEngine {
         }
 
         IfCommand ifCommand = new IfCommand(getCommand(rule), actionCommands);
-        ArrayList<Command> commands = new ArrayList<Command>(Collections.singleton(ifCommand));
+        ArrayList<Command> commands = new ArrayList<>(Collections.singleton(ifCommand));
         int linenumber = 0;
         boolean commented = false;
         String ruleName = rule.getFlag() == null ? MailCategoriesConstants.GENERAL_CATEGORY_ID : rule.getFlag();
@@ -210,18 +204,18 @@ public class SieveMailCategoriesRuleEngine implements MailCategoriesRuleEngine {
             List<TestCommand> commands = new ArrayList<>(2);
 
             if (rule.getFlag() == null) {
-                commands.add(new TestCommand(Commands.TRUE, Collections.emptyList(), new ArrayList<TestCommand>(0)));
+                commands.add(new TestCommand(Commands.TRUE, Collections.emptyList(), new ArrayList<>(0)));
             } else {
-                List<Object> flagArgList = new ArrayList<Object>(4);
+                List<Object> flagArgList = new ArrayList<>(4);
                 flagArgList.add(createTagArgument("is"));
                 flagArgList.add(Collections.singletonList(rule.getFlag()));
-                commands.add(new TestCommand(Commands.NOT, new ArrayList<>(), Collections.singletonList(new TestCommand(Commands.HASFLAG, flagArgList, new ArrayList<TestCommand>()))));
+                commands.add(new TestCommand(Commands.NOT, new ArrayList<>(), Collections.singletonList(new TestCommand(Commands.HASFLAG, flagArgList, new ArrayList<>()))));
             }
-            List<Object> argList = new ArrayList<Object>(4);
+            List<Object> argList = new ArrayList<>(4);
             argList.add(createTagArgument("contains"));
             argList.add(rule.getHeaders());
             argList.add(rule.getValues());
-            commands.add(new TestCommand(Commands.HEADER, argList, new ArrayList<TestCommand>()));
+            commands.add(new TestCommand(Commands.HEADER, argList, new ArrayList<>()));
             return new TestCommand(Commands.ALLOF, new ArrayList<>(), commands);
         }
 
